Class: DragDropObject

Inherits:
Object show all
Defined in:
lib/vr/dragdropformat.rb

Instance Method Summary collapse

Constructor Details

#initialize ⇒ DragDropObject

DragDropObject

A capsule for OLE Drag and Drop This is just a base class. Don't use this directly.

Methods

--- handle Returns a global heap handle containing the file pathes. --- free_handle Tries to free the handle. Please check you really need to free it, because sometimes your OS will free it automatically at the appropriate timing.



39
40
41
# File 'lib/vr/dragdropformat.rb', line 39

def initialize
  @__binarydata=""
end

Instance Method Details

#free_handle ⇒ Object



45
46
47
48
# File 'lib/vr/dragdropformat.rb', line 45

def free_handle
  GMEM::Free(@handle)
  @handle=0
end

#handle ⇒ Object



42
43
44
# File 'lib/vr/dragdropformat.rb', line 42

def handle
  @handle=GMEM::AllocStr(0x2000,@__binarydata)
end

#objectformat ⇒ Object



50
51
52
# File 'lib/vr/dragdropformat.rb', line 50

def objectformat
  self.class::FormatId
end