Class: VRTooltip::VRTooltipTool

Inherits:
Object
  • Object
show all
Defined in:
lib/vr/vrtooltip.rb

Overview

VRTooltip

This is a class for Tooltip window. Tooltip windows are created by VRScreen.createTooltip()

Methods

--- addTool(cntl,text) Assigns a tooltip text for ((|cntl|)). Returns a tooltip identifier. --- addToolArea([sx,sy,ex,ey],text,wnd=self) Assigns a tooltip text for the area in the parent window. ((|sx|)) and ((|sy|)) indicate left-top corner, and ((|ex|)) and ((|ey|)) indicate right-bottom corner. Returns a tooltip identifier. --- delTool(idf) Deletes a tool identified by ((|idf|)) returned by addTool or addToolArea --- enumTool Yields all tool identifiers. --- maxtipwidth --- maxtipwidth=(mw) About the tooltip width. If you are to use multiline tooltip, set this parameter. --- autopopTime --- autopopTime= Sets/Gets time length that tooltip remains visible. --- initialTime --- initialTime= Sets/Gets time length that the pointer must remain stationary. --- reshowTime --- reshowTime= Sets/Gets time length to reshow another tool's tooltip.

--- bkColor --- bkColor= Sets/Gets background color of tooltip window

--- textColor --- textColor= Sets/Gets text color of tooltip window

--- activate=(f) ((|f|)) is boolean. This activates/deactivates the tooltip.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(hwnd, uid, tool) ⇒ VRTooltipTool

Returns a new instance of VRTooltipTool.



99
100
101
# File 'lib/vr/vrtooltip.rb', line 99

def initialize(hwnd,uid,tool)
  @hwnd,@uid,@tool = hwnd,uid,tool
end

Instance Attribute Details

#hwnd ⇒ Object (readonly)

Returns the value of attribute hwnd.



96
97
98
# File 'lib/vr/vrtooltip.rb', line 96

def hwnd
  @hwnd
end

#tool ⇒ Object (readonly)

Returns the value of attribute tool.



98
99
100
# File 'lib/vr/vrtooltip.rb', line 98

def tool
  @tool
end

#uid ⇒ Object (readonly)

Returns the value of attribute uid.



97
98
99
# File 'lib/vr/vrtooltip.rb', line 97

def uid
  @uid
end