Class: VRTrackbar
Constant Summary
collapse
- WINCLASSINFO =
VRTrackbar
Trackbar.
Methods
--- position
Returns the position.
--- position=(pos)
Sets the position.
--- linesize
Returns the number of positions moved on by arrow keys.
--- linesize=(s)
Sets the number of positions mvoed on by arrow keys.
--- pagesize
Returns the number of positions moved on by [page up]/[pagedown] keys.
--- pagesize=(p)
Sets the number of positions moved on by [page up]/[pagedown] keys.
--- rangeMin
Returns minimum value of the trackbar.
--- rangeMin=(m)
Sets minimum value of the trackbar.
--- rangeMax
Returns maximum value of the trackbar.
--- rangeMax=(m)
Sets maximum value of the trackbar.
--- selStart
Returns the selection start of the trackbar.
--- selStart=(m)
Sets the selection start of the trackbar.
--- selEnd
Returns the selection end of the trackbar.
--- selEnd=(m)
Sets the selection end of the trackbar.
--- clearSel
Clears the selection.
["msctls_trackbar32",0]
Instance Attribute Summary
#_vr_notifyarg
Attributes inherited from VRControl
#handlers, #name, #parent
#parent, #screen
Instance Method Summary
collapse
#_vr_ntfyhandlers, #addFilterArg, #addNotifyHandler, #deleteFilterArg, #deleteNotifyHandler, #notifycontrolinit
Methods inherited from VRControl
Controltype, #add_parentcall, #call_parenthandler, #create, #setFont
#_init, #create, #exwinstyle, #hide, #maximizebox, #maximizebox=, #minimizebox, #minimizebox=, #setscreen, #sizebox, #sizebox=, #tabstop, #tabstop=, #winstyle
Instance Method Details
1172
1173
1174
|
# File 'lib/vr/vrcomctl.rb', line 1172
def clearSel
sendMessage WMsg::TBM_CLEARSEL,1,0
end
|
1138
1139
1140
|
# File 'lib/vr/vrcomctl.rb', line 1138
def linesize
sendMessage WMsg::TBM_GETLINESIZE,0,0
end
|
#linesize=(s) ⇒ Object
1141
1142
1143
|
# File 'lib/vr/vrcomctl.rb', line 1141
def linesize=(s)
sendMessage WMsg::TBM_SETLINESIZE,0,s.to_i
end
|
1144
1145
1146
|
# File 'lib/vr/vrcomctl.rb', line 1144
def pagesize
sendMessage WMsg::TBM_GETPAGESIZE,0,0
end
|
#pagesize=(s) ⇒ Object
1147
1148
1149
|
# File 'lib/vr/vrcomctl.rb', line 1147
def pagesize=(s)
sendMessage WMsg::TBM_SETPAGESIZE,0,s.to_i
end
|
1131
1132
1133
|
# File 'lib/vr/vrcomctl.rb', line 1131
def position
sendMessage WMsg::TBM_GETPOS,0,0
end
|
#position=(pos) ⇒ Object
1134
1135
1136
|
# File 'lib/vr/vrcomctl.rb', line 1134
def position=(pos)
sendMessage WMsg::TBM_SETPOS,1,pos.to_i
end
|
1157
1158
1159
|
# File 'lib/vr/vrcomctl.rb', line 1157
def rangeMax
sendMessage WMsg::TBM_GETRANGEMAX,0,0
end
|
#rangeMax=(m) ⇒ Object
1160
1161
1162
|
# File 'lib/vr/vrcomctl.rb', line 1160
def rangeMax=(m)
sendMessage WMsg::TBM_SETRANGEMAX,1,m.to_i
end
|
1151
1152
1153
|
# File 'lib/vr/vrcomctl.rb', line 1151
def rangeMin
sendMessage WMsg::TBM_GETRANGEMIN,0,0
end
|
#rangeMin=(m) ⇒ Object
1154
1155
1156
|
# File 'lib/vr/vrcomctl.rb', line 1154
def rangeMin=(m)
sendMessage WMsg::TBM_SETRANGEMIN,1,m.to_i
end
|
1169
1170
1171
|
# File 'lib/vr/vrcomctl.rb', line 1169
def selEnd
sendMessage WMsg::TBM_GETSELEND,0,0
end
|
1163
1164
1165
|
# File 'lib/vr/vrcomctl.rb', line 1163
def selStart
sendMessage WMsg::TBM_GETSELSTART,0,0
end
|
#selStart=(m) ⇒ Object
1166
1167
1168
|
# File 'lib/vr/vrcomctl.rb', line 1166
def selStart=(m)
sendMessage WMsg::TBM_SETSELSTART,1,m.to_i
end
|
1127
1128
1129
|
# File 'lib/vr/vrcomctl.rb', line 1127
def vrinit
super
end
|